@@ -21,16 +21,8 @@
 #include "kcmoduleproxy_p.h"
 
 #include <QApplication>
-#include <QCursor>
-#include <QtCore/QDataStream>
-#include <QKeyEvent>
-#include <QtCore/QFileInfo>
-#include <QFrame>
-#include <QLabel>
 #include <QLayout>
-#include <QtCore/QPoint>
 
-#include <QImage>
 
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
@@ -82,7 +74,7 @@ void KCModuleProxyPrivate::loadModule()
 {
     if (!topLayout) {
         topLayout = new QVBoxLayout(parent);
-        topLayout->setMargin(0);
+        topLayout->setContentsMargins(0, 0, 0, 0);
 
         QString name = modInfo.handle();
         name.replace(QLatin1Char('-'), QLatin1Char('_')); // hyphen is not allowed in dbus, only [A-Z][a-z][0-9]_
@@ -102,12 +94,13 @@ void KCModuleProxyPrivate::loadModule()
         kcm = KCModuleLoader::loadModule(modInfo, KCModuleLoader::Inline, parent, args);
 
         QObject::connect(kcm, SIGNAL(changed(bool)), parent, SLOT(_k_moduleChanged(bool)));
+        QObject::connect(kcm, SIGNAL(defaulted(bool)), parent, SLOT(_k_moduleDefaulted(bool)));
         QObject::connect(kcm, SIGNAL(destroyed()), parent, SLOT(_k_moduleDestroyed()));
         QObject::connect(kcm, &KCModule::quickHelpChanged, parent, &KCModuleProxy::quickHelpChanged);
         parent->setWhatsThis(kcm->quickHelp());
 
         if (kcm->layout()) {
-            kcm->layout()->setMargin(0);
+            kcm->layout()->setContentsMargins(0, 0, 0, 0);
         }
         topLayout->addWidget(kcm);
         if (!modInfo.handle().isEmpty()) {
@@ -192,6 +185,18 @@ void KCModuleProxyPrivate::_k_moduleChanged(bool c)
     emit q->changed(q);
 }
 
+void KCModuleProxyPrivate::_k_moduleDefaulted(bool d)
+{
+    if (defaulted == d) {
+        return;
+    }
+
+    Q_Q(KCModuleProxy);
+    defaulted = d;
+    emit q->changed(changed);
+    emit q->changed(q);
+}
+
 void KCModuleProxyPrivate::_k_moduleDestroyed()
 {
     kcm = nullptr;
@@ -268,6 +273,12 @@ bool KCModuleProxy::changed() const
     return d->changed;
 }
 
+bool KCModuleProxy::defaulted() const
+{
+    Q_D(const KCModuleProxy);
+    return d->defaulted;
+}
+
 KCModuleInfo KCModuleProxy::moduleInfo() const
 {
     Q_D(const KCModuleProxy);
