@@ -28,26 +28,25 @@
 #include <QLabel>
 #include <QLineEdit>
 #include <QPainter>
-#include <QBoxLayout>
 #include <QApplication>
 #include <QCheckBox>
 #include <QPushButton>
 #include <QStandardPaths>
 #include <QStyle>
 #include <QStyleOptionViewItem>
+#include <QVBoxLayout>
 
 #include <QDebug>
 #include <kurllabel.h>
 #include <kcmoduleinfo.h>
 #include <kcmoduleproxy.h>
 #include <kmessagebox.h>
-#include <kiconloader.h>
 #include <klocalizedstring.h>
 #include <kcategorydrawer.h>
 #include <kcategorizedview.h>
 #include <kcategorizedsortfilterproxymodel.h>
-#include <kaboutdata.h>
-#include <kaboutapplicationdialog.h>
+#include <KPluginMetaData>
+#include <KAboutPluginDialog>
 #include <KStandardGuiItem>
 
 #define MARGIN 5
@@ -206,7 +205,8 @@ void KPluginSelector::Private::DependenciesWidget::clearDependencies()
 void KPluginSelector::Private::DependenciesWidget::showDependencyDetails()
 {
     QString message = i18n("Automatic changes have been performed in order to satisfy plugin dependencies:\n");
-    foreach (const QString &dependency, dependencyMap.keys()) {
+    const auto lstKeys = dependencyMap.keys();
+    for (const QString &dependency : lstKeys) {
         if (dependencyMap[dependency].added) {
             message += i18n("\n    %1 plugin has been automatically checked because of the dependency of %2 plugin", dependency, dependencyMap[dependency].pluginCausant);
         } else {
@@ -283,9 +283,15 @@ KPluginSelector::KPluginSelector(QWidget *parent)
     connect(pluginDelegate, &Private::PluginDelegate::changed, this, &KPluginSelector::changed);
     connect(pluginDelegate, &Private::PluginDelegate::configCommitted, this, &KPluginSelector::configCommitted);
 
+    connect(this, &KPluginSelector::changed, [this]{ emit defaulted(isDefault()); });
+
     layout->addWidget(d->lineEdit);
     layout->addWidget(d->listView);
     layout->addWidget(d->dependenciesWidget);
+
+    // When a KPluginSelector instance gets focus,
+    // it should pass over the focus to its child searchbar.
+    setFocusProxy(d->lineEdit);
 }
 
 KPluginSelector::~KPluginSelector()
@@ -371,13 +377,15 @@ void KPluginSelector::save()
 
 void KPluginSelector::defaults()
 {
+    bool isChanged = false;
     for (int i = 0; i < d->pluginModel->rowCount(); i++) {
         const QModelIndex index = d->pluginModel->index(i, 0);
         PluginEntry *pluginEntry = static_cast<PluginEntry *>(index.internalPointer());
+        isChanged |= pluginEntry->pluginInfo.isPluginEnabled() != pluginEntry->pluginInfo.isPluginEnabledByDefault();
         d->pluginModel->setData(index, pluginEntry->pluginInfo.isPluginEnabledByDefault(), Qt::CheckStateRole);
     }
 
-    emit changed(true);
+    emit changed(isChanged);
 }
 
 bool KPluginSelector::isDefault() const
@@ -448,7 +456,7 @@ void KPluginSelector::Private::PluginModel::addPlugins(const QList<KPluginInfo>
 {
     QList<PluginEntry> listToAdd;
 
-    foreach (const KPluginInfo &pluginInfo, pluginList) {
+    for (const KPluginInfo &pluginInfo : pluginList) {
         PluginEntry pluginEntry;
         pluginEntry.category = categoryName;
         pluginEntry.pluginInfo = pluginInfo;
@@ -687,13 +695,17 @@ QSize KPluginSelector::Private::PluginDelegate::sizeHint(const QStyleOptionViewI
         i--;
     }
 
-    QFont font = titleFont(option.font);
-    QFontMetrics fmTitle(font);
+    const QFont font = titleFont(option.font);
+    const QFontMetrics fmTitle(font);
+    const QString text = index.model()->data(index, Qt::DisplayRole).toString();
+    const QString comment = index.model()->data(index, CommentRole).toString();
+    const int maxTextWidth = qMax(fmTitle.boundingRect(text).width(),
+                                  option.fontMetrics.boundingRect(comment).width());
 
-    return QSize(qMax(fmTitle.width(index.model()->data(index, Qt::DisplayRole).toString()),
-                      option.fontMetrics.width(index.model()->data(index, CommentRole).toString())) +
-                 (pluginSelector_d->showIcons ? KIconLoader::SizeMedium : 0) + MARGIN * i + pushButton->sizeHint().width() * j,
-                 qMax(KIconLoader::SizeMedium + MARGIN * 2, fmTitle.height() + option.fontMetrics.height() + MARGIN * 2));
+    const auto iconSize = pluginSelector_d->listView->style()->pixelMetric(QStyle::PM_IconViewIconSize);
+    return QSize(maxTextWidth +
+                 (pluginSelector_d->showIcons ? iconSize : 0) + MARGIN * i + pushButton->sizeHint().width() * j,
+                 qMax(iconSize + MARGIN * 2, fmTitle.height() + option.fontMetrics.height() + MARGIN * 2));
 }
 
 QList<QWidget *> KPluginSelector::Private::PluginDelegate::createItemWidgets(const QModelIndex &index) const
@@ -778,9 +790,12 @@ void KPluginSelector::Private::PluginDelegate::slotStateChanged(bool state)
     const_cast<QAbstractItemModel *>(index.model())->setData(index, state, Qt::CheckStateRole);
 }
 
-void KPluginSelector::Private::PluginDelegate::emitChanged()
+void KPluginSelector::Private::PluginDelegate::emitChanged(bool state)
 {
-    emit changed(true);
+    const QModelIndex index = focusedIndex();
+    PluginEntry *pluginEntry = index.model()->data(index, PluginEntryRole).value<PluginEntry *>();
+
+    emit changed(pluginEntry->pluginInfo.isPluginEnabled() != state);
 }
 
 void KPluginSelector::Private::PluginDelegate::slotAboutClicked()
@@ -788,29 +803,10 @@ void KPluginSelector::Private::PluginDelegate::slotAboutClicked()
     const QModelIndex index = focusedIndex();
     const QAbstractItemModel *model = index.model();
 
-    const QString name = model->data(index, NameRole).toString();
-    const QString comment = model->data(index, CommentRole).toString();
-    const QString author = model->data(index, AuthorRole).toString();
-    const QString email = model->data(index, EmailRole).toString();
-    const QString website = model->data(index, WebsiteRole).toString();
-    const QString version = model->data(index, VersionRole).toString();
-    const QString license = model->data(index, LicenseRole).toString();
+    PluginEntry *pluginEntry = model->data(index, PluginEntryRole).value<PluginEntry *>();
+    KPluginMetaData pluginMetaData = pluginEntry->pluginInfo.toMetaData();
 
-    KAboutData aboutData(name, name, version, comment, KAboutLicense::byKeyword(license).key(), QString(), QString(), website);
-    aboutData.setProgramIconName(index.model()->data(index, Qt::DecorationRole).toString());
-    const QStringList authors = author.split(QLatin1Char(','));
-    const QStringList emails = email.split(QLatin1Char(','));
-    if (authors.count() == emails.count()) {
-        int i = 0;
-        foreach (const QString &author, authors) {
-            if (!author.isEmpty()) {
-                aboutData.addAuthor(author, QString(), emails[i]);
-            }
-            i++;
-        }
-    }
-    KAboutApplicationDialog aboutPlugin(aboutData, itemView());
-    aboutPlugin.setWindowTitle(i18nc("Used only for plugins", "About %1", aboutData.displayName()));
+    KAboutPluginDialog aboutPlugin(pluginMetaData, itemView());
     aboutPlugin.exec();
 }
 
@@ -837,7 +833,8 @@ void KPluginSelector::Private::PluginDelegate::configure(const QModelIndex& inde
     // The first proxy is owned by the dialog itself
     QWidget *moduleProxyParentWidget = &configDialog;
 
-    foreach (const KService::Ptr &servicePtr, pluginInfo.kcmServices()) {
+    const auto lstServices = pluginInfo.kcmServices();
+    for (const KService::Ptr &servicePtr : lstServices) {
         if (!servicePtr->noDisplay()) {
             KCModuleInfo moduleInfo(servicePtr);
             KCModuleProxy *currentModuleProxy = new KCModuleProxy(moduleInfo, moduleProxyParentWidget, pluginSelector_d->kcmArguments);
@@ -893,15 +890,15 @@ void KPluginSelector::Private::PluginDelegate::configure(const QModelIndex& inde
         configDialog.setLayout(layout);
 
         if (configDialog.exec() == QDialog::Accepted) {
-            foreach (KCModuleProxy *moduleProxy, moduleProxyList) {
-                QStringList parentComponents = moduleProxy->moduleInfo().service()->property(QStringLiteral("X-KDE-ParentComponents")).toStringList();
+            for (KCModuleProxy *moduleProxy : qAsConst(moduleProxyList)) {
+                const QStringList parentComponents = moduleProxy->moduleInfo().service()->property(QStringLiteral("X-KDE-ParentComponents")).toStringList();
                 moduleProxy->save();
-                foreach (const QString &parentComponent, parentComponents) {
+                for (const QString &parentComponent : parentComponents) {
                     emit configCommitted(parentComponent.toLatin1());
                 }
             }
         } else {
-            foreach (KCModuleProxy *moduleProxy, moduleProxyList) {
+            for (KCModuleProxy *moduleProxy : qAsConst(moduleProxyList)) {
                 moduleProxy->load();
             }
         }
@@ -913,7 +910,7 @@ void KPluginSelector::Private::PluginDelegate::configure(const QModelIndex& inde
 
 void KPluginSelector::Private::PluginDelegate::slotDefaultClicked()
 {
-    foreach (KCModuleProxy *moduleProxy, moduleProxyList) {
+    for (KCModuleProxy *moduleProxy : qAsConst(moduleProxyList)) {
         moduleProxy->defaults();
     }
 }
